<?php
/**
 * ownCloud
 *
 * @author Jörn Friedrich Dreyer <jfd@owncloud.com>
 * @copyright (C) 2014 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */


namespace OCA\ObjectStore;
use \OC\Files\ObjectStore\AbstractObjectStore;

class Rackspace extends AbstractObjectStore {

	
	/**
	 * @var \OpenCloud\ObjectStore\Resource\Container
	 */
	private $container;

	public function __construct($params) {
		if (!isset($params['username']) || !isset($params['apiKey']) ) {
			throw new \Exception("Access Key and Secret have to be configured.");
		}

		$client = new \OpenCloud\Rackspace($params['url'], array(
			'username' => $params['username'],
			'apiKey' => $params['apiKey']
		));

		
		/** @var $objectStoreService \OpenCloud\ObjectStore\Service **/
		$objectStoreService = $client->objectStoreService(null, $params['region']);

		$this->container = $objectStoreService->getContainer($params['container']);

		if ( ! $this->is_dir('/') ) {
			$this->mkdir('/');
		}
		//set the user via parent constructor, also initializes the root of the filecache
		parent::__construct($params);
	}

	protected function deleteObject($urn) {
		$object = $this->container->getObject($urn);
		$object->delete();
	}
	
	protected function getObject($urn, $tmpFile) {
		$object = $this->container->getObject($urn);

		/** @var $objectContent \Guzzle\Http\EntityBody **/
		$objectContent = $object->getContent();

		$objectContent->rewind();
		$stream = $objectContent->getStream();
		file_put_contents($tmpFile, $stream);
	}
	
	protected function createObject($urn, $tmpFile = null) {
		$fileData = '';
		if ($tmpFile) {
			$fileData = fopen($tmpFile, 'r');
		}

		$this->container->uploadObject($urn, $fileData);
	}

}
